summaryrefslogtreecommitdiffstats
path: root/kexi/plugins/forms/kexidbtextwidgetinterface.h
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-06-25 05:28:35 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-06-25 05:28:35 +0000
commitf008adb5a77e094eaf6abf3fc0f36958e66896a5 (patch)
tree8e9244c4d4957c36be81e15b566b4aa5ea26c982 /kexi/plugins/forms/kexidbtextwidgetinterface.h
parent1210f27b660efb7b37ff43ec68763e85a403471f (diff)
downloadkoffice-f008adb5a77e094eaf6abf3fc0f36958e66896a5.tar.gz
koffice-f008adb5a77e094eaf6abf3fc0f36958e66896a5.zip
TQt4 port koffice
This should enable compilation under both Qt3 and Qt4; fixes for any missed components will be forthcoming git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/applications/koffice@1238284 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'kexi/plugins/forms/kexidbtextwidgetinterface.h')
-rw-r--r--kexi/plugins/forms/kexidbtextwidgetinterface.h12
1 files changed, 6 insertions, 6 deletions
diff --git a/kexi/plugins/forms/kexidbtextwidgetinterface.h b/kexi/plugins/forms/kexidbtextwidgetinterface.h
index ca10fc4e..6e0299c0 100644
--- a/kexi/plugins/forms/kexidbtextwidgetinterface.h
+++ b/kexi/plugins/forms/kexidbtextwidgetinterface.h
@@ -25,7 +25,7 @@
namespace KexiDB {
class QueryColumnInfo;
}
-class QFrame;
+class TQFrame;
//! @short An interface providing common text editor's functionality
/*! Widgets (e.g. KexiDBLineEdit, KexiDBTextEdit) implementing KexiFormDataItemInterface
@@ -37,13 +37,13 @@ class KEXIFORMUTILS_EXPORT KexiDBTextWidgetInterface
~KexiDBTextWidgetInterface();
//! Called from KexiFormDataItemInterface::setColumnInfo(KexiDB::QueryColumnInfo* cinfo) implementation.
- void setColumnInfo(KexiDB::QueryColumnInfo* cinfo, QWidget *w);
+ void setColumnInfo(KexiDB::QueryColumnInfo* cinfo, TQWidget *w);
- //! Called from paintEvent( QPaintEvent *pe ) method of the data aware widget.
- void paint( QFrame *w, QPainter *p, bool textIsEmpty, int alignment, bool hasFocus );
+ //! Called from paintEvent( TQPaintEvent *pe ) method of the data aware widget.
+ void paint( TQFrame *w, TQPainter *p, bool textIsEmpty, int tqalignment, bool hasFocus );
- //! Called from event( QEvent * e ) method of the data aware widget.
- void event( QEvent * e, QWidget *w, bool textIsEmpty );
+ //! Called from event( TQEvent * e ) method of the data aware widget.
+ void event( TQEvent * e, TQWidget *w, bool textIsEmpty );
protected:
//! parameters for displaying autonumber sign